@@ -42,7 +42,13 @@ class Machine:
         if isinstance(state, str):
             return self.get_state_from_state_name(state), None
         elif isinstance(state, tuple):
-            return state[0], state[1]
+            if isinstance(state[0], str):
+                return self.get_state_from_state_name(state[0]), state[1]
+            elif issubclass(state[0], BaseState):
+                return state[0], state[1]
+            else:
+                raise StateDoesNotExistError
+            
         elif issubclass(state, BaseState):
             return state, None
         else:
